@@ -3,9 +3,7 @@
 
 import hashlib
 import socket
-from urllib.error import HTTPError
 from urllib import parse
-import logging
 
 # 定义常量
 CONFIGURATIONS = "configurations"
@@ -32,13 +30,9 @@ def no_key_cache_key(namespace, key):
 
 # 返回是否获取到的值，不存在则返回None
 def get_value_from_dict(namespace_cache, key):
-    if namespace_cache:
-        kv_data = namespace_cache.get(CONFIGURATIONS)
-        if kv_data is None:
-            return None
-        if key in kv_data:
-            return kv_data[key]
-    return None
+    namespace_cache = namespace_cache or {}
+    kv_data = namespace_cache.get(CONFIGURATIONS) or {}
+    return kv_data.get(key)
 
 
 def init_ip():
@@ -51,15 +45,3 @@ def init_ip():
         s.close()
     return ""
 
-
-def http_request(client, url, timeout, headers=None):
-    try:
-        headers = headers or {}
-        res = client.get(url, headers=headers, timeout=timeout)
-        return res.status_code, res.content.decode("utf-8")
-    except HTTPError as e:
-        if e.code == 304:
-            logging.getLogger(__name__).warning("http_request error,code is 304, maybe you should check secret")
-            return 304, None
-        logging.getLogger(__name__).warning("http_request error,code is %d, msg is %s", e.code, e.msg)
-        raise e
